#
# $Header: proadaxt.mk.pp,v 4011600.4 91/01/09 17:12:29 atam Exp $ proadaxt.mk.pp Copyr (c) 1989 Oracle
#
#
# proadaxt.mk - Makefile which is used to make...
#
#       sqlmenux (dmux) - the SQL*Menu executable with Ada user exit code
#                         linked in (to the built-in SQL*Forms).  
#
# References: 
#   1) "ORACLE Installation and User's Guide"
#   2) "SQL*Menu User's Guide"
#
# Required files for User Exit example:
#
#   concats.a    - Specification for sample ada user exit source module.
#   concat.pad   - Body for sample user exit source module (Pro*Ada program)
#                - Uses "EXEC IAF GET..." to read data from a SQL*Forms field.
#                - This is the recommended method.
#
#   adamain.a    - ada main program that builds argc and argv and passes 
#                  them to a C main program.
#
#   iapxtb.c     - sample user exit entry point table
#
#
# General Procedure for adding user exits.
#   a) Create your own ada user exit file.
#   b) Insert the user exit routine names into the database by using genxtb.
#   c) Generate a new iapxtb.c using "genxtb". 
#   d) Rebuild the SQL*Forms executable adding an "x" to its name to denote
#      the inclusion of user exits: 
#
#               $ make -f proadaxt.mk sqlmenux
#
# To use "genxtb":
#   a) Run "genxtb" to create IAPXTB table [first time only]:          
#               $ genxtb username/password
#   b) Generate and Run the application "genxtb" to add exits to IAPXTB table
#      in the database:
#               $ generate -to genxtb       
#               $ runform genxtb       
#   c) Run "genxtb" to create "iapxtb.c" with current exits:
#               $ genxtb username/password iapxtb.c
#

CC=/usr/5bin/cc

CFLAGS=-I. -O

LDFLAGS=-Bstatic

RANLIB=ranlib

ECHO=$(ORACLE_HOME)/bin/echodo

PCC=$(ORACLE_HOME)/bin/pcc
PCCINC=$(ORACLE_HOME)/c/lib
PCCFLAGS=include=$(PCCINC) ireclen=132 oreclen=132 select_error=no

LIBORA=$(ORACLE_HOME)/rdbms/lib/libora.a 

LIBSQL=$(ORACLE_HOME)/rdbms/lib/libsql.a

LIBOCIC=$(ORACLE_HOME)/rdbms/lib/libocic.a

LIBPCC=$(ORACLE_HOME)/rdbms/lib/libpcc.a

LIBPRO=$(ORACLE_HOME)/rdbms/lib/libpro.a

LIBPSD=$(ORACLE_HOME)/c/lib/libpsd.a

LIBPLUS=$(ORACLE_HOME)/sqlplus/lib/libplus.a

LIBPLS=$(ORACLE_HOME)/rdbms/lib/libpls.a

LIBKNL=$(ORACLE_HOME)/rdbms/lib/libknl.a

LIBFORMS=$(ORACLE_HOME)/forms/lib/libforms.a

LIBFORMS30=$(ORACLE_HOME)/forms30/lib/libforms30.a

LIBFORMS30P=$(ORACLE_HOME)/forms30/lib/libforms30p.a

LIBFORMS30C=$(ORACLE_HOME)/forms30/lib/libforms30c.a

LIBFORMS30X=$(ORACLE_HOME)/forms30/lib/libforms30x.a

LIBFORMS30M=$(ORACLE_HOME)/forms30/lib/libforms30m.a

LIBOKT=$(ORACLE_HOME)/orakit/lib/libokt.a

LIBOKTC=$(ORACLE_HOME)/orakit/lib/liboktc.a

LIBOKTX=$(ORACLE_HOME)/orakit/lib/liboktx.a

LIBOKTM=$(ORACLE_HOME)/orakit/lib/liboktm.a

OTHERLIBS=`cat $(ORACLE_HOME)/rdbms/lib/sysliblist`

CONFIG=$(ORACLE_HOME)/rdbms/lib/config.o

OSNTAB=$(ORACLE_HOME)/rdbms/lib/osntab.o

LIBTCP=$(ORACLE_HOME)/tcp/lib/libtcp.a

NETLIBS=$(OSNTAB) $(ORACLE_HOME)/rdbms/lib/libsqlnet.a 

STLIBS=$(ORACLE_HOME)/rdbms/lib/osntabst.o $(CONFIG)

PROLIBS=$(LIBOCIC) $(LIBSQL)

PCCLIBS=$(LIBPCC) $(LIBSQL) $(LIBOCIC) $(LIBPRO) $(LIBPCC)

FRMLIBS=$(ORACLE_HOME)/forms/lib/scp.o $(LIBFORMS)

XLIBS=-lXaw -lXt -lXmu -lX11 -lm

CLIBS=$(OTHERLIBS)

.SUFFIXES: .o .c .pad .a 

ADAHOME=$(ORACLE_HOME)/ada

ADACC=ada -e
ADALD=a.ld -v

# Ada compilation environment in this subdirectory
#

LIBMENU=$(ORACLE_HOME)/menu/lib/libmenu.a

LIBORAST=$(LIBORA) $(LIBPLS) $(LIBKNL) $(LIBORA) $(LIBKNL) $(LIBPLS)

MENULINK=$(LIBSQL) $(LIBOCIC) $(NETLIBS) $(LIBORA) $(CLIBS)
MENULINKST=$(LIBSQL) $(STLIBS) $(LIBORAST) $(CLIBS)

IAPXIT=iapxtb.o 

$(ADAENV):
	-$(MKADAENV)

sqlmenux: $(IAPXIT) concat adamain
	@$(ECHO) $(ADALD) adamain -o sqlmenux $(ORACLE_HOME)/menu/lib/dmu.o \
	$(IAPXIT) $(LIBMENU) $(LIBPLUS) $(LIBFORMS) $(MENULINK)
	rm -f dmux 
	ln sqlmenux dmux

# User Exit.
concat: $(ADAENV) concats concatb

# User Exit Specification.
concats: concats.a
	$(ADACC) concats.a > concats.err

# User Exit Body.
concat_dcl.a:
concat.a: concat.pad
	$(PCC) $(PCCFLAGS) iname=concat.pad
concatb: $(ADAENV) concat.pad concat.a concat_dcl.a
	$(ADACC) concat_dcl.a > concat_dcl.err
	$(ADACC) concat.a > concat.err

adamain: $(ADAENV) adamain.a
	$(ADACC) adamain.a > adamain.err

adamain.a: $(ORACLE_HOME)/forms/lib/ada/adamain.a
	cp $(ORACLE_HOME)/forms/lib/ada/adamain.a .

concat.pad: $(ORACLE_HOME)/forms/lib/ada/concat.pad
	cp $(ORACLE_HOME)/forms/lib/ada/concat.pad .

concats.a: $(ORACLE_HOME)/forms/lib/ada/concats.a
	cp $(ORACLE_HOME)/forms/lib/ada/concats.a .
