#
# $Header: procobxt.mk.pp,v 4011600.8 91/01/09 17:13:12 atam Exp $ procobxt.mk.pp Copyr (c) 1990 Oracle
#
#
# procobxt.mk - Makefile which is used to make...
#
#       sqlmenux (dmux) - the SQL*Menu executable with Cobol user exit 
#                         code linked in.  
#
# References: 
#   1) "ORACLE Installation and User's Guide"
#   2) "SQL*Menu User's Guide"
#
# Required files for User Exit example:
#
#   samplexit.pco - sample user exit source module (Pro*Cobol program)
#
#   iapxtb.c      - sample user exit entry point table
#
#
# General Procedure for adding user exits.
#   a) Create your own cobol user exit file.
#   b) Insert the user exit routine names into the database by using genxtb.
#   c) Generate a new iapxtb.c using "genxtb". 
#   d) Rebuild the SQL*Menu executable adding an "x" to its name to denote
#      the inclusion of user exits: 
#
#               $ make -f procobxt.mk sqlmenux
#
# To use "genxtb":
#   a) Run "genxtb" to create IAPXTB table [first time only]:          
#               $ genxtb username/password
#   b) Generate and Run the application "genxtb" to add exits to IAPXTB table
#      in the database:
#               $ generate -to genxtb       
#               $ runform genxtb       
#   c) Run "genxtb" to create "iapxtb.c" with current exits:
#               $ genxtb username/password iapxtb.c
#

CC=/usr/5bin/cc

CFLAGS=-I. -O

LDFLAGS=-Bstatic

RANLIB=ranlib

ECHO=$(ORACLE_HOME)/bin/echodo

PCC=$(ORACLE_HOME)/bin/pcc
PCCINC=$(ORACLE_HOME)/c/lib
PCCFLAGS=include=$(PCCINC) ireclen=132 oreclen=132 select_error=no

LIBORA=$(ORACLE_HOME)/rdbms/lib/libora.a 

LIBSQL=$(ORACLE_HOME)/rdbms/lib/libsql.a

LIBOCIC=$(ORACLE_HOME)/rdbms/lib/libocic.a

LIBPCC=$(ORACLE_HOME)/rdbms/lib/libpcc.a

LIBPRO=$(ORACLE_HOME)/rdbms/lib/libpro.a

LIBPSD=$(ORACLE_HOME)/c/lib/libpsd.a

LIBPLUS=$(ORACLE_HOME)/sqlplus/lib/libplus.a

LIBPLS=$(ORACLE_HOME)/rdbms/lib/libpls.a

LIBKNL=$(ORACLE_HOME)/rdbms/lib/libknl.a

LIBFORMS=$(ORACLE_HOME)/forms/lib/libforms.a

LIBFORMS30=$(ORACLE_HOME)/forms30/lib/libforms30.a

LIBFORMS30P=$(ORACLE_HOME)/forms30/lib/libforms30p.a

LIBFORMS30C=$(ORACLE_HOME)/forms30/lib/libforms30c.a

LIBFORMS30X=$(ORACLE_HOME)/forms30/lib/libforms30x.a

LIBFORMS30M=$(ORACLE_HOME)/forms30/lib/libforms30m.a

LIBOKT=$(ORACLE_HOME)/orakit/lib/libokt.a

LIBOKTC=$(ORACLE_HOME)/orakit/lib/liboktc.a

LIBOKTX=$(ORACLE_HOME)/orakit/lib/liboktx.a

LIBOKTM=$(ORACLE_HOME)/orakit/lib/liboktm.a

OTHERLIBS=`cat $(ORACLE_HOME)/rdbms/lib/sysliblist`

CONFIG=$(ORACLE_HOME)/rdbms/lib/config.o

OSNTAB=$(ORACLE_HOME)/rdbms/lib/osntab.o

LIBTCP=$(ORACLE_HOME)/tcp/lib/libtcp.a

NETLIBS=$(OSNTAB) $(ORACLE_HOME)/rdbms/lib/libsqlnet.a 

STLIBS=$(ORACLE_HOME)/rdbms/lib/osntabst.o $(CONFIG)

PROLIBS=$(LIBOCIC) $(LIBSQL)

PCCLIBS=$(LIBPCC) $(LIBSQL) $(LIBOCIC) $(LIBPRO) $(LIBPCC)

FRMLIBS=$(ORACLE_HOME)/forms/lib/scp.o $(LIBFORMS)

XLIBS=-lXaw -lXt -lXmu -lX11 -lm

CLIBS=$(OTHERLIBS)

.SUFFIXES: .o .c .pc .pco .cbl .cob

LIBMENU=$(ORACLE_HOME)/menu/lib/libmenu.a

OSNTAB=$(ORACLE_HOME)/rdbms/lib/osntab.o

NETLIBS=$(OSNTAB) $(ORACLE_HOME)/rdbms/lib/libsqlnet.a 

COBSQLINT=$(ORACLE_HOME)/cobol/lib/cobsqlintf.o \
	$(ORACLE_HOME)/cobol/lib/cobsqlusrxt.o \
	$(ORACLE_HOME)/cobol/lib/invstr.o

COBOL=cob

COBFLAGS=-x

LIBORAST=$(LIBORA) $(LIBPLS) $(LIBKNL) $(LIBORA) $(LIBKNL) $(LIBPLS)

MENULINK=$(LIBSQL) $(LIBOCIC) $(NETLIBS) $(LIBORA) $(CLIBS)
MENULINKST=$(LIBSQL) $(STLIBS) $(LIBORAST) $(CLIBS)

IAPXIT=samplexit.$(COBEXT) iapxtb.o 

sqlmenux: $(IAPXIT) $(OSNTAB)
	@$(ECHO) $(COBOL) $(COBFLAGS) -o sqlmenux \
	$(ORACLE_HOME)/menu/lib/dmu.o $(IAPXIT) $(COBSQLINT) \
	$(LIBMENU) $(LIBPLUS) $(LIBFORMS) $(MENULINK)
	rm -f dmux 
	ln sqlmenux dmux

samplexit.pco: $(ORACLE_HOME)/forms/lib/cobol/samplexit.pco
	cp $(ORACLE_HOME)/forms/lib/cobol/samplexit.pco .

.c.o:
	$(CC) -c $(CFLAGS) -I$(ORACLE_HOME)/forms/lib $*.c

.pco.$(COBEXT):
	$(PCC) $(PCCFLAGS) iname=$*.pco
