# 
# $Header: sqlmenu.mk.pp,v 4011600.3 91/01/09 17:11:20 atam Exp $ sqlmenu.mk.pp Copyr (c) 1989 Oracle
# 
#
# sqlmenu.mk - Makefile which is used to make...
#
#       1) sqlmenu (dmu, dmm, dmd) - the SQL*Menu executables at install time.
#       2) sqlmenux (dmux)         - the SQL*Menu executable with user exit
#                                    code linked in (to the built-in
#                                    SQL*Forms).
#
# References: 
#   1) "ORACLE Installation and User's Guide"
#   2) "SQL*Menu User's Guide"
#
# General Usage for linking:
#
#           $ make -f sqlmenu.mk install
#
# Required files for User Exit example:
#
#   iaxpcc.pc  - sample user exit source module   (Pro*C program)
#              - Uses "EXEC IAF GET..." to read data from a SQL*Forms field.
#
#   iapxtb.c   - sample user exit entry point table
#
#
# General Procedure for adding user exits.
#   a) Add the user exit functions to the file "iaxpcc.pc".
#   b) Insert the user exit routine names into the database by using genxtb.
#   c) Generate a new iapxtb.c using "genxtb".
#   d) Rebuild the SQL*Menu executable adding an "x" to its name to denote
#      the inclusion of user exits:
#
#               $ make -f sqlmenu.mk sqlmenux
#
# To use "genxtb":
#   a) Run "genxtb" to create IAPXTB table [first time only]:
#               $ genxtb username/password
#   b) Generate and Run the application "genxtb" to add exits to IAPXTB table
#      in the database:
#               $ generate -to genxtb
#               $ runform genxtb
#   c) Run "genxtb" to create "iapxtb.c" with current exits:
#               $ genxtb username/password iapxtb.c
#

CC=/usr/5bin/cc

CFLAGS=-I. -O

LDFLAGS=-Bstatic

RANLIB=ranlib

ECHO=$(ORACLE_HOME)/bin/echodo

PCC=$(ORACLE_HOME)/bin/pcc
PCCINC=$(ORACLE_HOME)/c/lib
PCCFLAGS=include=$(PCCINC) ireclen=132 oreclen=132 select_error=no

LIBORA=$(ORACLE_HOME)/rdbms/lib/libora.a 

LIBSQL=$(ORACLE_HOME)/rdbms/lib/libsql.a

LIBOCIC=$(ORACLE_HOME)/rdbms/lib/libocic.a

LIBPCC=$(ORACLE_HOME)/rdbms/lib/libpcc.a

LIBPRO=$(ORACLE_HOME)/rdbms/lib/libpro.a

LIBPSD=$(ORACLE_HOME)/c/lib/libpsd.a

LIBPLUS=$(ORACLE_HOME)/sqlplus/lib/libplus.a

LIBPLS=$(ORACLE_HOME)/rdbms/lib/libpls.a

LIBKNL=$(ORACLE_HOME)/rdbms/lib/libknl.a

LIBFORMS=$(ORACLE_HOME)/forms/lib/libforms.a

LIBFORMS30=$(ORACLE_HOME)/forms30/lib/libforms30.a

LIBFORMS30P=$(ORACLE_HOME)/forms30/lib/libforms30p.a

LIBFORMS30C=$(ORACLE_HOME)/forms30/lib/libforms30c.a

LIBFORMS30X=$(ORACLE_HOME)/forms30/lib/libforms30x.a

LIBFORMS30M=$(ORACLE_HOME)/forms30/lib/libforms30m.a

LIBOKT=$(ORACLE_HOME)/orakit/lib/libokt.a

LIBOKTC=$(ORACLE_HOME)/orakit/lib/liboktc.a

LIBOKTX=$(ORACLE_HOME)/orakit/lib/liboktx.a

LIBOKTM=$(ORACLE_HOME)/orakit/lib/liboktm.a

OTHERLIBS=`cat $(ORACLE_HOME)/rdbms/lib/sysliblist`

CONFIG=$(ORACLE_HOME)/rdbms/lib/config.o

OSNTAB=$(ORACLE_HOME)/rdbms/lib/osntab.o

LIBTCP=$(ORACLE_HOME)/tcp/lib/libtcp.a

NETLIBS=$(OSNTAB) $(ORACLE_HOME)/rdbms/lib/libsqlnet.a 

STLIBS=$(ORACLE_HOME)/rdbms/lib/osntabst.o $(CONFIG)

PROLIBS=$(LIBOCIC) $(LIBSQL)

PCCLIBS=$(LIBPCC) $(LIBSQL) $(LIBOCIC) $(LIBPRO) $(LIBPCC)

FRMLIBS=$(ORACLE_HOME)/forms/lib/scp.o $(LIBFORMS)

XLIBS=-lXaw -lXt -lXmu -lX11 -lm

CLIBS=$(OTHERLIBS)

.SUFFIXES: .o .c .pc

LIBMENU=$(ORACLE_HOME)/menu/lib/libmenu.a

LIBORAST= $(LIBORA) $(LIBPLS) $(LIBKNL) $(LIBORA) $(LIBKNL) $(LIBPLS)

MENULINK= $(LIBSQL) $(LIBOCIC) $(NETLIBS) $(LIBORA) $(CLIBS)
MENULINKST= $(LIBSQL) $(STLIBS) $(LIBORAST) $(CLIBS)

IAPXIT=iaxpcc.o iapxtb.o

install: clean setup

clean:
	-rm -f dmu dmm dmd
dmu:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmu.o  $(LIBMENU) $(LIBPLUS) \
	$(LIBFORMS) $(MENULINK)
dmm:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmmdrv.o $(LIBMENU)  $(MENULINK)
dmd:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmd.o $(LIBMENU)  $(MENULINK)

dmust:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmu.o  $(LIBMENU) $(LIBPLUS) \
	$(LIBFORMS) $(MENULINKST)

dmmst:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmmdrv.o  $(LIBMENU) $(MENULINKST)

dmdst:
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmd.o $(LIBMENU) $(MENULINKST)

setup:  dmu dmm dmd
	rm -f $(ORACLE_HOME)/bin/dmu
	rm -f $(ORACLE_HOME)/bin/dmm
	rm -f $(ORACLE_HOME)/bin/dmd
	mv dmu dmm dmd $(ORACLE_HOME)/bin
	-chmod 751 $(ORACLE_HOME)/bin/dmu
	-chmod 751 $(ORACLE_HOME)/bin/dmm
	-chmod 751 $(ORACLE_HOME)/bin/dmd

singletask: dmust dmmst dmdst
	rm -f $(ORACLE_HOME)/bin/dmust
	rm -f $(ORACLE_HOME)/bin/dmmst
	rm -f $(ORACLE_HOME)/bin/dmdst
	mv dmust dmmst dmdst $(ORACLE_HOME)/bin
	-chmod 751 $(ORACLE_HOME)/bin/dmust
	-chmod 751 $(ORACLE_HOME)/bin/dmmst
	-chmod 751 $(ORACLE_HOME)/bin/dmdst

sqlmenux : $(IAPXIT)
	@$(ECHO) $(CC) $(LDFLAGS) -o $@ dmu.o $(IAPXIT) $(LIBMENU) $(LIBPLUS) \
	$(LIBFORMS) $(MENULINK)
	rm -f dmux 
	ln sqlmenux dmux

iaxpcc.pc: $(ORACLE_HOME)/forms/lib/iaxpcc.pc
	cp $(ORACLE_HOME)/forms/lib/iaxpcc.pc  .

.c.o:
	$(CC) -c $(CFLAGS) -I$(ORACLE_HOME)/forms/lib $*.c

.pc.o:
	$(PCC) $(PCCFLAGS) iname=$*.pc
	$(CC) -c $(CFLAGS) -I$(ORACLE_HOME)/forms/lib $*.c
